#
# spec file for package yast2-services-manager
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


######################################################################
#
# IMPORTANT: Please do not change spec file in build service directly
#            Use https://github.com/yast/yast-services-manager repo
#
######################################################################

Name:           yast2-services-manager
Version:        5.0.1
Release:        1.2
Summary:        YaST2 - Services Manager
Group:          System/YaST
License:        GPL-2.0-or-later
URL:            https://github.com/yast/yast-services-manager

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  ruby
BuildRequires:  update-desktop-files
# 'target' argument for Installation::AutoClient#export method
BuildRequires:  yast2 >= 4.3.10
BuildRequires:  yast2-ruby-bindings >= 1.2.0
# To show service logs
BuildRequires:  yast2-journal >= 4.1.1
# Support for 'data' directory in rake install task
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake) >= 0.1.7
BuildRequires:  yast2-devtools >= 4.2.2
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)
# The tests need systemctl
BuildRequires:  pkgconfig(systemd)

Requires:       ruby
 # 'target' argument for Installation::AutoClient#export method
Requires:       yast2 >= 4.3.10
Requires:       yast2-ruby-bindings >= 1.2.0

# To show service logs
Suggests:       yast2-journal >= 4.1.1

Obsoletes:      yast2-runlevel

# need new enough installation for its inst clients
Conflicts:      yast2-installation < 3.1.32
Conflicts:      yast2-runlevel

Supplements:    autoyast(services-manager)

BuildArch:      noarch

%description
Provides user interface and libraries to configure systemd
services and targets.

%prep
%setup -q

%build

%check
rake test:unit

%install
%yast_install
%yast_metainfo

%files
%{yast_clientdir}
%{yast_moduledir}
%{yast_schemadir}
%{yast_libdir}
%{yast_ydatadir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_icondir}
%doc %{yast_docdir}
%license COPYING

%changelog
* Tue Jan 28 2025 Stefan Hundhammer <shundhammer@suse.com>
- Remove nscd-related code (bsc#1236308)
- 5.0.1
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Mon May 15 2023 Stefan Hundhammer <shundhammer@suse.com>
- Improved help text for services table (bsc#1211320)
- 4.6.1
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Thu Jul  7 2022 Fabian Vogt <fvogt@suse.com>
- Explicitly pull in systemctl for buildtime tests (jsc#SMO-84)
- 4.5.1
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Wed Aug 18 2021 David Diaz <dgonzalez@suse.com>
- Update known systemd states and substates (bsc#1189572)
- 4.4.1
* Tue Apr 20 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0 (bsc#1185510)
* Mon Feb 15 2021 Josef Reidinger <jreidinger@suse.com>
- Adapted unit test to recent changes in Yast::Report (related to
  bsc#1179893).
- 4.3.6
* Thu Aug 27 2020 Martin Vidner <mvidner@suse.com>
- Re-enable service table sorting (bsc#1165388, bsc#1174615).
- 4.3.5
* Mon Aug 10 2020 schubi@suse.de
- AutoYaST: Added supplements: autoyast(services_manager) into the
  spec file in order to install this packages if the section has
  been defined in the AY configuration file (bsc#1146494).
- 4.3.4
* Mon Aug 10 2020 Martin Vidner <mvidner@suse.com>
- Fix changing other services than the user expects (bsc#1165388,
  bsc#1174615)
- 4.3.3
* Wed Jul 29 2020 Josef Reidinger <jreidinger@suse.com>
- Fix detection of modifications in AutoYaST config mode
  (bsc#1173408)
- Fix remembering of services configuration in AutoYaST config mode
  (bsc#1173408)
- 4.3.2
* Tue Jun 30 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Honor the 'target' argument when cloning the system. If it is
  set to 'compact', it only exports those services which start
  mode is not set to their predefined values (bsc#1172749).
- 4.3.1
* Tue May 12 2020 josef Reidinger <jreidinger@localhost>
- Autoyast schema: Allow optional types for string and map objects
  (bsc#1170886)
- 4.3.0
* Fri Sep  6 2019 schubi@suse.de
- Set BaseTargets::GRAPHICAL and Target::GRAPHICAL if package "xdm"
  will be installed (instead of xorg-x11-server) (bsc#1140735).
- 4.2.5
* Tue Aug 27 2019 schubi@suse.de
- Set X-SuSE-YaST-AutoInstResource in desktop file (bsc#144894).
- 4.2.4
* Thu Aug 22 2019 schubi@suse.de
- Using rb_default_ruby_abi tag in the spec file in order to
  handle several ruby versions (bsc#1146403).
- 4.2.3
* Fri May 31 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.2
* Wed May  8 2019 Stefan Hundhammer <shundhammer@suse.com>
- Adapted systemd states to upstream changes:
  New stop-watchdog, no more stop-sigabrt (bsc#1134571)
- 4.2.0
* Wed Feb 13 2019 schubi@suse.de
- Upgrade: Do not write default target if it has not been set.
  (bsc#1125144)
- 4.1.14
* Fri Feb  8 2019 schubi@suse.de
- Reporting a warning if a none existing default target will be
  written (bsc#1046083).
- 4.1.13
* Tue Jan 29 2019 dgonzalez@suse.com
- Includes the associated socket status, if applicable, as part of
  the service details (bsc#119276)
- 4.1.12
* Wed Dec 12 2018 schubi@suse.de
- Fix: Do not crash in chroot environment (bsc#1113732)
- 4.1.11
* Wed Dec 12 2018 Josef Reidinger <jreidinger@suse.com>
- always use absolute path to binaries (bsc#1118291)
- 4.1.10
* Mon Nov 26 2018 Noah Davis <noahadvs@gmail.com>
- Provide icon with module (boo#1109310)
- 4.1.9
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Wed Sep 19 2018 knut.anderssen@suse.com
- Adapted to use the Y2Firewall::Firewalld::Zone object returned by
  Y2Firewall::Firewalld::Interface#zone instead of a String.
- Adapted to use the new Y2Firewall::Firewalld::Interface objects
  instead of a hash (fate#324662)
- 4.1.8
* Wed Sep  5 2018 igonzalezsosa@suse.com
- Bring back the ServicesManagerTargetClass#modified= method
  (bsc#1107240).
- 4.1.7
* Mon Aug 27 2018 jlopez@suse.com
- Add help for buttons in the dialog (related to bsc#1089999 and
  fate#319428).
- 4.1.6
* Thu Aug 23 2018 dgonzalez@suse.com
- Update calls to YaST2 systemd classes (related to fate#319428)
- 4.1.5
* Thu Aug 23 2018 jlopez@suse.com
- Add confirmation popup with summary of changes and highlight
  changes over each service.
- Disable Apply button when there are no changes.
- Part of fate#319428.
- 4.1.4
* Wed Aug 22 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Tue Aug 14 2018 igonzalezsosa@suse.com
- Add support for systemd services that can only be started
  on-demand (fate#319428 and bsc#1104568).
- 4.1.3
* Wed Aug  8 2018 igonzalezsosa@suse.com
- Add support to AutoYaST to set services to be started on demand
  (related to fate#319428).
- Improve AutoYaST error handling when configuring services.
- 4.1.2
* Mon Aug  6 2018 jlopez@suse.com
- Added button to show journal logs (related to fate#319427).
- 4.1.1
* Fri Aug  3 2018 jlopez@suse.com
- Added button to apply changes without closing the Services
  Manager dialog (part of fate#319428).
- 4.1.0
* Wed Aug  1 2018 igonzalezsosa@suse.com
- Fix support to handle services during early 1st stage
  (related to fate#319428).
- 4.0.6
* Wed Jul 25 2018 jlopez@suse.com
- Show systemd state and substate for each service,
  e.g. "Active (Running)" (bsc#1080738).
- Added new menu button to select the service start mode (on boot,
  on demand or manually) (fate#319427).
- 4.0.5
* Wed Jun 27 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.0.4
* Mon Feb 12 2018 knut.anderssen@suse.com
- Replace SuSEFirewall2 by firewalld (fate#323460)
- 4.0.3
* Mon Feb 12 2018 jreidinger@suse.com
- Drop xinetd service protected for xvnc as it now uses service
  (fate#323373)
- 4.0.2
* Mon Oct 16 2017 jreidinger@suse.com
- respect target level specified in control file (bsc#1063216)
- 4.0.1
* Wed Aug 30 2017 mvidner@suse.com
- Use fewer calls of systemctl to speed up startup (bsc#1045658)
- 4.0.0
* Wed Aug  2 2017 jreidinger@suse.com
- Optimize services manager output for ncurses on 80x24
  (bsc#993826)
- 3.3.1
* Wed Jul 12 2017 jreidinger@suse.com
- Fix failing ERB template in ruby 2.4 (will be default for SLE15
  so part of bsc#1044312)
- 3.3.0
* Tue Feb 14 2017 schubi@suse.de
- Added lib/services-manager/clients/*.rb to spec file
  (FATE#321738).
* Mon Feb 13 2017 schubi@suse.de
- AutoYaST: "Write" can be called in first and second installation
  stage (FATE#321738).
- 3.2.1
* Thu Jan 19 2017 schubi@suse.de
- Using systemctl calls (is-active, is-enabled) to evaluate if the
  service is enabled/active (bnc#1017166, bnc#1012047)
- AY-Import: Filter out all YaST services which should e.g. not be
  restarted while installation.(bnc#956043)
- 3.2.0
* Tue Nov 15 2016 igonzalezsosa@suse.com
- Use the X-SuSE-YaST-AutoInstResourceAliases key to get rid
  of the runlevel.desktop file (related to bsc#887115 and
  bsc#1008301)
- 3.1.43
* Wed Jan 13 2016 igonzalezsosa@suse.com
- Add X-SuSE-YaST-AutoInstSchema declaration so
  services-manager.rnc could be included in yast2-schema package
- Fix validation of AutoYaST profile (bsc#954412)
- 3.1.42
* Wed Nov 25 2015 crojasaragonez@hotmail.com
- Closing window with x icon fixed (bsc#956917)
- 3.1.41
* Mon Nov 23 2015 locilka@suse.com
- Service state 'activating' is considered to be 'active',
  'deactivating' is 'inactive' and 'reloading' is 'active'.
  This fixes the second stage of AutoYaST installation getting hung
  in certain cases as it tried to restart itself (bsc#956043).
- 3.1.40
* Fri Dec 19 2014 schubi@suse.de
- AutoYaST: Moved code from autoyast2 package to import function of
  services_manager_target. (bnc#909745)
- 3.1.39
* Wed Dec 17 2014 schubi@suse.de
- AutoYaST import: initialize Yast::I18n correctly
  (bnc#909768)
- 3.1.38
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Wed Dec  3 2014 locilka@suse.com
- Fixed adjusting service state according to new settings, already
  loaded services were ignored (bnc#906730)
- 3.1.37
* Mon Nov 17 2014 ancor@suse.com
- From SLE12 maintenance: fixed installation to use the
  localized version of the default target name (bnc#895023).
- 3.1.36
* Tue Nov  4 2014 jreidinger@suse.com
- Do not overwrite predefined target value in live installer
  (bnc#891213)
- 3.1.35
* Tue Oct 14 2014 cwh@suse.com
- Added minimal commandline support: just 'help' (bnc#893622)
- 3.1.34
* Fri Sep 19 2014 locilka@suse.com
- Defining safe minimal width of the Default Target UI entry
  (bnc#897443)
- 3.1.33
* Fri Sep 19 2014 locilka@suse.com
- Defining textdomain in ServicesManagerTarget::BaseTargets module
  (bnc#892366)
- 3.1.32
* Thu Sep  4 2014 mvidner@suse.com
- Use a more flexible rubygem requirement syntax (bnc#895069)
- 3.1.31
* Mon Aug 25 2014 schubi@suse.de
- Autoyast: Moved minimal configuration to a central place in
  inst_finish. (bnc#886464)
- 3.1.30
* Tue Aug 19 2014 locilka@suse.com
- Targets marked for translations, adjusting UI in a way that even
  longer targets (translations) fit into it (bnc#892366)
- 3.1.29
* Mon Jul 28 2014 schubi@suse.de
- Do not set default target while autoyast installation/update.
  (bnc#889055)
- 3.1.28
* Fri Jul 25 2014 ancor@suse.com
- Ensures that the errors list is cleared if the user decides to
  continue after a failure (by delegating ServiceManager.errors to
  ServiceManagerService)
- Fixes bnc#888555
- 3.1.27
* Thu Jul 24 2014 locilka@suse.com
- While saving services state (activate/deactivate), do not touch
  a service, that is already in the desired state (bnc#884756)
- 3.1.26
* Wed Jul 23 2014 locilka@suse.com
- Showing info that Services Manager hasn't been configured yet in
  AutoYast till it's cloned from the system or user enters
  the module and saves its configuration (bnc#887694)
- 3.1.25
* Tue Jul 22 2014 locilka@suse.com
- Using new library ServicesProposal, that holds information about
  enabled/disabled services during installation, for exporting the
  services configuration for AutoYast at the end of installation
  (bnc#887688)
- 3.1.24
* Tue Jul 22 2014 locilka@suse.com
- Services Manager client for AutoYast marked as clonable (meaning:
  can read the current system state) (bnc#887115)
- 3.1.23
* Thu Jul 17 2014 locilka@suse.com
- Fixed AutoYast summary to show both enabled and disabled services
- Fixed reading targets - now they read in all cases except the
  initial installation where systemctl doesn't work in chroot
- Fixed AutoYast schema to allow service or listentry as AutoYast
  by default exports all single entries as 'listentry'
- All bnc#887695 and bnc#887115
- 3.1.22
* Mon Jul 14 2014 locilka@suse.com
- ServicesManagerServiceClass and ServicesManagerTargetClass
  switched to using lazy loading of system(ctl) data
- Fixed Export AutoYast functionality to return the currently
  supported and documented format
- Added tests for all the other AutoYast formats supported
  for Import (all bnc#885800)
- 3.1.21
* Tue Jul  8 2014 locilka@suse.com
- Function 'localize' moved to ServicesManagerTarget library and
  added a test case (bnc#886117)
- 3.1.20
* Mon Jul  7 2014 locilka@suse.com
- Fixed broken N_(...) call (bnc#886040)
- 3.1.19
* Fri Jul  4 2014 locilka@suse.com
- Default systemd target names marked for translation (bnc#884339)
- 3.1.18
* Thu Jul  3 2014 locilka@suse.com
- Marked "runlevel" as not clonable, the functionality is there
  for importing old profiles only (bnc#873604)
- 3.1.17
* Wed Jul  2 2014 vmoravec@suse.com
- Fix failing tests
- 3.1.16
* Tue Jul  1 2014 vmoravec@suse.com
- Fix issues with ServicesManagerTarget (bnc#869656, bnc#867759,
  bnc#875098)
- 3.1.15
* Fri Jun  6 2014 locilka@suse.com
- AutoYast summary - hard-coded ERB moved to separate file
  to be able to generate translations (bnc#878606)
- Added missing textdomain (bnc#881277)
- 3.1.14
* Mon May 12 2014 vmoravec@suse.com
- Fix displaying icon twice in control centre (bnc#874124)
- 3.1.13
* Thu Apr 10 2014 vmoravec@suse.com
- Add support for legacy runlevel autoyast profile and improve
  profile specifications (bnc#865347)
- 3.1.12
* Tue Mar 18 2014 vmoravec@suse.com
- Do not crash installation with empty services list (bnc#868614)
- 3.1.11
* Mon Mar 17 2014 vmoravec@suse.com
- Do not disable services not listed in autoyast profile
  in second stage (bnc#868042)
- 3.1.10
* Fri Mar  7 2014 vmoravec@suse.com
- Respect the user preference for default target (bnc#867125)
- 3.1.9
* Fri Feb 28 2014 vmoravec@suse.com
- Reload target detection after install config change (bnc#866292)
- 3.1.8
* Wed Feb 26 2014 vmoravec@suse.com
- Select the current default target in the proposal (bnc#865357)
- 3.1.7
* Tue Feb 25 2014 vmoravec@suse.com
- Fix crashing installer if canceled target proposal (bnc#865354)
- 3.1.6
* Thu Feb 20 2014 vmoravec@suse.com
- Fix wrong target selection (bnc#864073)
- 3.1.5
* Thu Feb 20 2014 vmoravec@suse.com
- Add explicit empty default target (bnc#864073)
- 3.1.4
* Mon Feb 17 2014 jreidinger@suse.com
- fix latest fix for constant refine (bnc#864055)
- 3.1.3
* Thu Feb 13 2014 jreidinger@suse.com
- avoid constant redefine warning (BNC#861529)
- 3.1.2
* Wed Feb 12 2014 jreidinger@suse.com
- fix namespace collision for minimal installation
- 3.1.1
* Wed Feb 12 2014 vmoravec@suse.com
- main version change
- README.md update
- 3.1.0
* Tue Feb 11 2014 jreidinger@suse.com
- fix dependencies to not allow old yast2-installation
- 0.0.24
* Fri Feb  7 2014 jreidinger@suse.com
- support minimal installation (FATE#313149)
- 0.0.23
* Tue Jan  7 2014 locilka@suse.com
- Reusing already defined constant in SystemdTarget instead of
  redefining it again
- 0.0.22
* Tue Dec  3 2013 vmoravec@suse.com
- 0.0.21
- Fix installation proposal for default taret
- Do not validate new target outside of normal mode
* Thu Nov 28 2013 vmoravec@suse.com
- 0.0.20
- fix prep in spec
* Wed Nov 27 2013 vmoravec@suse.com
- 0.0.19
- use versioned tarball
* Wed Nov 27 2013 vmoravec@suse.com
- 0.0.18
- remove dependency on ruby 2.0
* Wed Nov 27 2013 vmoravec@suse.com
- fix publishing export method in SystemdService module
- 0.0.17
* Tue Nov 26 2013 vmoravec@suse.cz
- fix missing dependency on Mode module
- 0.0.16
* Fri Nov 22 2013 vmoravec@suse.com
- 0.0.15
- do not call dbus during installation for setting
  default_target
* Mon Nov 11 2013 vmoravec@suse.com
- 0.0.14
- obsoletes yast2-runlevel package
* Mon Nov 11 2013 vmoravec@suse.com
- 0.0.13
- group base target constants for better referencing from
  withing other modules and clients
* Wed Nov  6 2013 vmoravec@suse.com
- 0.0.12
- complete autoyast support
* Mon Nov  4 2013 vmoravec@suse.com
- 0.0.11
- list missing LSB services bnc#846422
* Fri Oct 25 2013 vmoravec@suse.com
- 0.0.10
- add alias services for services-manager client
- replace old tests with rspec tests
- add yast clients: target_proposal, services_proposal, target_finish
- various fixes of modules' API
* Sun Sep 15 2013 tchvatal@suse.com
- Fix the ruby dep and drop clean section as it is useless.
* Fri Sep 13 2013 vmoravec@suse.com
- 0.0.9
- Refactoring of module API
- Added tests
* Wed Jul 10 2013 locilka@suse.com
- 0.0.8
- Added full AutoYast support
- Temporarily disabled tests for openSUSE 13.1 and further
- Added dependency on ruby-bindings >= 1.2.0
* Thu Jul  4 2013 locilka@suse.com
- Dialogs and their handling split into separate file to be used
  from Autoyast
- Double click in table of services enables/disables the selected
  service
* Thu Jun 27 2013 vmoravec@suse.com
- 0.0.7
- Use updated yast2-ruby-bindings
- Adapt namespace to new yast2-ruby-bindings
* Fri Jun 21 2013 locilka@suse.com
- 0.0.6
- Added infrastructure for tests and one simple exemplary test
* Fri Jun 21 2013 locilka@suse.com
- 0.0.5
- SystemdTarget.all changed to return hash instead of array
- Using target description in UI
* Thu Jun 20 2013 locilka@suse.com
- 0.0.4
- Initial version: Services can be started and stopped, enabled
  or disabled. Default target can be set.
